@@ -4,10 +4,8 @@ R_CallMethodDef library_WRAPPER_AUTO_H5[] = {
 {"R_H5check_version", (DL_FUNC) &R_H5check_version, 3},
 {"R_H5close", (DL_FUNC) &R_H5close, 0},
 {"R_H5dont_atexit", (DL_FUNC) &R_H5dont_atexit, 0},
-{"R_H5free_memory", (DL_FUNC) &R_H5free_memory, 2},
 {"R_H5garbage_collect", (DL_FUNC) &R_H5garbage_collect, 0},
 {"R_H5get_libversion", (DL_FUNC) &R_H5get_libversion, 3},
-{"R_H5is_library_threadsafe", (DL_FUNC) &R_H5is_library_threadsafe, 1},
 {"R_H5open", (DL_FUNC) &R_H5open, 0},
 {"R_H5set_free_list_limits", (DL_FUNC) &R_H5set_free_list_limits, 6},
 {NULL, NULL, 0}
@@ -334,7 +332,6 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pget_class_name", (DL_FUNC) &R_H5Pget_class_name, 1},
 {"R_H5Pget_class_parent", (DL_FUNC) &R_H5Pget_class_parent, 1},
 {"R_H5Pget_copy_object", (DL_FUNC) &R_H5Pget_copy_object, 2},
-{"R_H5Pget_core_write_tracking", (DL_FUNC) &R_H5Pget_core_write_tracking, 3},
 {"R_H5Pget_create_intermediate_group", (DL_FUNC) &R_H5Pget_create_intermediate_group, 2},
 {"R_H5Pget_data_transform", (DL_FUNC) &R_H5Pget_data_transform, 3},
 {"R_H5Pget_driver", (DL_FUNC) &R_H5Pget_driver, 1},
@@ -394,7 +391,6 @@ R_CallMethodDef library_WRAPPER_AUTO_H5P[] = {
 {"R_H5Pset_chunk", (DL_FUNC) &R_H5Pset_chunk, 3},
 {"R_H5Pset_chunk_cache", (DL_FUNC) &R_H5Pset_chunk_cache, 4},
 {"R_H5Pset_copy_object", (DL_FUNC) &R_H5Pset_copy_object, 2},
-{"R_H5Pset_core_write_tracking", (DL_FUNC) &R_H5Pset_core_write_tracking, 3},
 {"R_H5Pset_create_intermediate_group", (DL_FUNC) &R_H5Pset_create_intermediate_group, 2},
 {"R_H5Pset_data_transform", (DL_FUNC) &R_H5Pset_data_transform, 2},
 {"R_H5Pset_deflate", (DL_FUNC) &R_H5Pset_deflate, 2},
