@@ -149,46 +149,6 @@ SEXP R_H5Dfill(SEXP R_fill, SEXP R_fill_type, SEXP R_buf, SEXP R_buf_type, SEXP
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Dflush(hid_t dset_id); */
-SEXP R_H5Dflush(SEXP R_dset_id){
-  int vars_protected=0;
-  hid_t dset_id = SEXP_to_longlong(R_dset_id, 0);
-  herr_t return_val = H5Dflush(dset_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
-/* H5_DLL herr_t H5Dformat_convert(hid_t dset_id); */
-SEXP R_H5Dformat_convert(SEXP R_dset_id){
-  int vars_protected=0;
-  hid_t dset_id = SEXP_to_longlong(R_dset_id, 0);
-  herr_t return_val = H5Dformat_convert(dset_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL hid_t H5Dget_access_plist(hid_t dset_id); */
 SEXP R_H5Dget_access_plist(SEXP R_dset_id){
   int vars_protected=0;
@@ -209,44 +169,6 @@ SEXP R_H5Dget_access_plist(SEXP R_dset_id){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Dget_chunk_index_type(hid_t did, H5D_chunk_index_t *idx_type); */
-SEXP R_H5Dget_chunk_index_type(SEXP R_did, SEXP R_idx_type){
-  hsize_t size_helper;
-  SEXP R_helper = R_NilValue;
-  int vars_protected=0;
-  R_idx_type = PROTECT(duplicate(R_idx_type));
-  vars_protected++;
-  hid_t did = SEXP_to_longlong(R_did, 0);
-  H5D_chunk_index_t* idx_type;
-  if(XLENGTH(R_idx_type) == 0) {
-    idx_type = NULL;
-  }
-  else {
-    R_helper = PROTECT(RToH5(R_idx_type, h5_datatype[DT_H5D_chunk_index_t], XLENGTH(R_idx_type)));
-    idx_type= (H5D_chunk_index_t*) VOIDPTR(R_helper);
-    vars_protected++;
-  }
-  herr_t return_val = H5Dget_chunk_index_type(did, idx_type);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  size_helper = guess_nelem(R_idx_type, h5_datatype[DT_H5D_chunk_index_t]);
-  R_idx_type = PROTECT(H5ToR_single_step(idx_type, h5_datatype[DT_H5D_chunk_index_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 2));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SET_VECTOR_ELT(__ret_list, 1, R_idx_type);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 2));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_STRING_ELT(__ret_list_names, 1, mkChar("idx_type"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL hid_t H5Dget_create_plist(hid_t dset_id); */
 SEXP R_H5Dget_create_plist(SEXP R_dset_id){
   int vars_protected=0;
@@ -444,26 +366,6 @@ SEXP R_H5Dread(SEXP R_dset_id, SEXP R_mem_type_id, SEXP R_mem_space_id, SEXP R_f
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Drefresh(hid_t dset_id); */
-SEXP R_H5Drefresh(SEXP R_dset_id){
-  int vars_protected=0;
-  hid_t dset_id = SEXP_to_longlong(R_dset_id, 0);
-  herr_t return_val = H5Drefresh(dset_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL herr_t H5Dset_extent(hid_t dset_id, const hsize_t size[]); */
 SEXP R_H5Dset_extent(SEXP R_dset_id, SEXP R_size){
   SEXP R_helper = R_NilValue;
